@@ -17,9 +17,13 @@ class EventHandler {
   virtual ~EventHandler() = default;
 };
 
+/// If you want to use the Hyprland IPC, simply use IPC::inst() to get the singleton instance.
+/// Do not create multiple instances.
 class IPC {
+ protected:
+  IPC();  // use IPC::inst() instead.
+
  public:
-  IPC();
   ~IPC();
   static IPC& inst();
 
@@ -42,8 +46,7 @@ class IPC {
   util::JsonParser parser_;
   std::list<std::pair<std::string, EventHandler*>> callbacks_;
   int socketfd_;  // the hyprland socket file descriptor
-  bool running_ = true;
+  pid_t socketOwnerPid_;
+  bool running_ = true;  // the ipcThread will stop running when this is false
 };
-
-inline bool modulesReady = false;
 };  // namespace waybar::modules::hyprland
