@@ -8,6 +8,8 @@
 #include <cstring>
 #include <memory>
 #include <mutex>
+#include <stdexcept>
+#include <string>
 
 #include "ipc.hpp"
 #include "util/sleeper_thread.hpp"
@@ -25,21 +27,21 @@ class Ipc {
     std::string payload;
   };
 
-  sigc::signal<void, const struct ipc_response &> signal_event;
-  sigc::signal<void, const struct ipc_response &> signal_cmd;
+  sigc::signal<void, const struct ipc_response&> signal_event;
+  sigc::signal<void, const struct ipc_response&> signal_cmd;
 
-  void sendCmd(uint32_t type, const std::string &payload = "");
-  void subscribe(const std::string &payload);
+  void sendCmd(uint32_t type, const std::string& payload = "");
+  void subscribe(const std::string& payload);
   void handleEvent();
-  void setWorker(std::function<void()> &&func);
+  void setWorker(std::function<void()>&& func);
 
  protected:
   static inline const std::string ipc_magic_ = "i3-ipc";
   static inline const size_t ipc_header_size_ = ipc_magic_.size() + 8;
 
   const std::string getSocketPath() const;
-  int open(const std::string &) const;
-  struct ipc_response send(int fd, uint32_t type, const std::string &payload = "");
+  int open(const std::string&) const;
+  struct ipc_response send(int fd, uint32_t type, const std::string& payload = "");
   struct ipc_response recv(int fd);
 
   int fd_;
