@@ -14,14 +14,20 @@ waybar::modules::Image::Image(const std::string& id, const Json::Value& config)
 
   size_ = config["size"].asInt();
 
-  interval_ = config_["interval"].asInt();
+  interval_ = config_["interval"] == "once"
+                  ? std::chrono::milliseconds::max()
+                  : std::chrono::milliseconds(std::max(
+                        1L,  // Minimum 1ms due to millisecond precision
+                        static_cast<long>(
+                            (config_["interval"].isNumeric() ? config_["interval"].asDouble() : 0) *
+                            1000)));
 
   if (size_ == 0) {
     size_ = 16;
   }
 
-  if (interval_ == 0) {
-    interval_ = INT_MAX;
+  if (interval_.count() == 0) {
+    interval_ = std::chrono::milliseconds::max();
   }
 
   delayWorker();
@@ -30,13 +36,12 @@ waybar::modules::Image::Image(const std::string& id, const Json::Value& config)
 void waybar::modules::Image::delayWorker() {
   thread_ = [this] {
     dp.emit();
-    auto interval = std::chrono::seconds(interval_);
-    thread_.sleep_for(interval);
+    thread_.sleep_for(interval_);
   };
 }
 
 void waybar::modules::Image::refresh(int sig) {
-  if (sig == SIGRTMIN + config_["signal"].asInt()) {
+  if (config_["signal"].isInt() && sig == SIGRTMIN + config_["signal"].asInt()) {
     thread_.wake_up();
   }
 }
