@@ -9,23 +9,23 @@
 
 namespace waybar::modules::river {
 
-static void listen_focused_view(void *data, struct zriver_seat_status_v1 *zriver_seat_status_v1,
-                                const char *title) {
-  static_cast<Window *>(data)->handle_focused_view(title);
+static void listen_focused_view(void* data, struct zriver_seat_status_v1* zriver_seat_status_v1,
+                                const char* title) {
+  static_cast<Window*>(data)->handle_focused_view(title);
 }
 
-static void listen_focused_output(void *data, struct zriver_seat_status_v1 *zriver_seat_status_v1,
-                                  struct wl_output *output) {
-  static_cast<Window *>(data)->handle_focused_output(output);
+static void listen_focused_output(void* data, struct zriver_seat_status_v1* zriver_seat_status_v1,
+                                  struct wl_output* output) {
+  static_cast<Window*>(data)->handle_focused_output(output);
 }
 
-static void listen_unfocused_output(void *data, struct zriver_seat_status_v1 *zriver_seat_status_v1,
-                                    struct wl_output *output) {
-  static_cast<Window *>(data)->handle_unfocused_output(output);
+static void listen_unfocused_output(void* data, struct zriver_seat_status_v1* zriver_seat_status_v1,
+                                    struct wl_output* output) {
+  static_cast<Window*>(data)->handle_unfocused_output(output);
 }
 
-static void listen_mode(void *data, struct zriver_seat_status_v1 *zriver_seat_status_v1,
-                        const char *mode) {
+static void listen_mode(void* data, struct zriver_seat_status_v1* zriver_seat_status_v1,
+                        const char* mode) {
   // This module doesn't care
 }
 
@@ -36,36 +36,36 @@ static const zriver_seat_status_v1_listener seat_status_listener_impl{
     .mode = listen_mode,
 };
 
-static void handle_global(void *data, struct wl_registry *registry, uint32_t name,
-                          const char *interface, uint32_t version) {
+static void handle_global(void* data, struct wl_registry* registry, uint32_t name,
+                          const char* interface, uint32_t version) {
   if (std::strcmp(interface, zriver_status_manager_v1_interface.name) == 0) {
     version = std::min<uint32_t>(version, 2);
-    static_cast<Window *>(data)->status_manager_ = static_cast<struct zriver_status_manager_v1 *>(
+    static_cast<Window*>(data)->status_manager_ = static_cast<struct zriver_status_manager_v1*>(
         wl_registry_bind(registry, name, &zriver_status_manager_v1_interface, version));
   }
 
   if (std::strcmp(interface, wl_seat_interface.name) == 0) {
     version = std::min<uint32_t>(version, 1);
-    static_cast<Window *>(data)->seat_ = static_cast<struct wl_seat *>(
-        wl_registry_bind(registry, name, &wl_seat_interface, version));
+    static_cast<Window*>(data)->seat_ =
+        static_cast<struct wl_seat*>(wl_registry_bind(registry, name, &wl_seat_interface, version));
   }
 }
 
-static void handle_global_remove(void *data, struct wl_registry *registry, uint32_t name) {
+static void handle_global_remove(void* data, struct wl_registry* registry, uint32_t name) {
   /* Ignore event */
 }
 
 static const wl_registry_listener registry_listener_impl = {.global = handle_global,
                                                             .global_remove = handle_global_remove};
 
-Window::Window(const std::string &id, const waybar::Bar &bar, const Json::Value &config)
+Window::Window(const std::string& id, const waybar::Bar& bar, const Json::Value& config)
     : waybar::ALabel(config, "window", id, "{}", 30),
       status_manager_{nullptr},
       seat_{nullptr},
       bar_(bar),
       seat_status_{nullptr} {
-  struct wl_display *display = Client::inst()->wl_display;
-  struct wl_registry *registry = wl_display_get_registry(display);
+  struct wl_display* display = Client::inst()->wl_display;
+  struct wl_registry* registry = wl_display_get_registry(display);
   wl_registry_add_listener(registry, &registry_listener_impl, this);
   wl_display_roundtrip(display);
 
@@ -95,7 +95,7 @@ Window::~Window() {
   }
 }
 
-void Window::handle_focused_view(const char *title) {
+void Window::handle_focused_view(const char* title) {
   // don't change the label on unfocused outputs.
   // this makes the current output report its currently focused view, and unfocused outputs will
   // report their last focused views. when freshly starting the bar, unfocused outputs don't have a
@@ -106,13 +106,17 @@ void Window::handle_focused_view(const char *title) {
     label_.hide();  // hide empty labels or labels with empty format
   } else {
     label_.show();
-    label_.set_markup(fmt::format(format_, Glib::Markup::escape_text(title).raw()));
+    auto text = fmt::format(fmt::runtime(format_), Glib::Markup::escape_text(title).raw());
+    label_.set_markup(text);
+    if (tooltipEnabled()) {
+      label_.set_tooltip_markup(text);
+    }
   }
 
   ALabel::update();
 }
 
-void Window::handle_focused_output(struct wl_output *output) {
+void Window::handle_focused_output(struct wl_output* output) {
   if (output_ == output) {  // if we focused the output this bar belongs to
     label_.get_style_context()->add_class("focused");
     ALabel::update();
@@ -120,7 +124,7 @@ void Window::handle_focused_output(struct wl_output *output) {
   focused_output_ = output;
 }
 
-void Window::handle_unfocused_output(struct wl_output *output) {
+void Window::handle_unfocused_output(struct wl_output* output) {
   if (output_ == output) {  // if we unfocused the output this bar belongs to
     label_.get_style_context()->remove_class("focused");
     ALabel::update();
