@@ -3,13 +3,16 @@
 #include <json/value.h>
 #include <spdlog/spdlog.h>
 
+#include <algorithm>
+#include <utility>
+
 namespace waybar::util {
 
 int default_priority_function(std::string& key) { return 0; }
 
 RegexCollection::RegexCollection(const Json::Value& map, std::string default_repr,
-                                 std::function<int(std::string&)> priority_function)
-    : default_repr(default_repr) {
+                                 const std::function<int(std::string&)>& priority_function)
+    : default_repr(std::move(default_repr)) {
   if (!map.isObject()) {
     spdlog::warn("Mapping is not an object");
     return;
@@ -31,11 +34,12 @@ RegexCollection::RegexCollection(const Json::Value& map, std::string default_rep
   std::sort(rules.begin(), rules.end(), [](Rule& a, Rule& b) { return a.priority > b.priority; });
 }
 
-std::string& RegexCollection::find_match(std::string& value, bool& matched_any) {
+std::string RegexCollection::find_match(std::string& value, bool& matched_any) {
   for (auto& rule : rules) {
-    if (std::regex_search(value, rule.rule)) {
+    std::smatch match;
+    if (std::regex_search(value, match, rule.rule)) {
       matched_any = true;
-      return rule.repr;
+      return match.format(rule.repr.data());
     }
   }
 
